; The CMD file.
;
; Two parts: 1. Command definition and  2. State entry
; (state entry is after the commands def section)
;
; 1. Command definition
; ---------------------
; Note: The commands are CASE-SENSITIVE, and so are the command names.
; The eight directions are:
;   B, DB, D, DF, F, UF, U, UB     (all CAPS)
;   corresponding to back, down-back, down, downforward, etc.
; The six buttons are:
;   a, b, c, x, y, z               (all lower case)
;   In default key config, abc are are the bottom, and xyz are on the
;   top row. For 2 button characters, we recommend you use a and b.
;   For 6 button characters, use abc for kicks and xyz for punches.
;
; Each [Command] section defines a command that you can use for
; state entry, as well as in the CNS file.
; The command section should look like:
;
;   [Command]
;   name = some_name
;   command = the_command
;   time = time (optional)
;   buffer.time = time (optional)
;
; - some_name
;   A name to give that command. You'll use this name to refer to
;   that command in the state entry, as well as the CNS. It is case-
;   sensitive (QCB_a is NOT the same as Qcb_a or QCB_A).
;
; - command
;   list of buttons or directions, separated by commas. Each of these
;   buttons or directions is referred to as a "symbol".
;   Directions and buttons can be preceded by special characters:
;   slash (/) - means the key must be held down
;          egs. command = /D       ;hold the down direction
;               command = /DB, a   ;hold down-back while you press a
;   tilde (~) - to detect key releases
;          egs. command = ~a       ;release the a button
;               command = ~D, F, a ;release down, press fwd, then a
;          If you want to detect "charge moves", you can specify
;          the time the key must be held down for (in game-ticks)
;          egs. command = ~30a     ;hold a for at least 30 ticks, then release
;   dollar ($) - Direction-only: detect as 4-way
;          egs. command = $D       ;will detect if D, DB or DF is held
;               command = $B       ;will detect if B, DB or UB is held
;   plus (+) - Buttons only: simultaneous press
;          egs. command = a+b      ;press a and b at the same time
;               command = x+y+z    ;press x, y and z at the same time
;   greater-than (>) - means there must be no other keys pressed or released
;                      between the previous and the current symbol.
;          egs. command = a, >~a   ;press a and release it without having hit
;                                  ;or released any other keys in between
;   You can combine the symbols:
;     eg. command = ~30$D, a+b     ;hold D, DB or DF for 30 ticks, release,
;                                  ;then press a and b together
;
;   Note: Successive direction symbols are always expanded in a manner similar
;         to this example:
;           command = F, F
;         is expanded when MUGEN reads it, to become equivalent to:
;           command = F, >~F, >F
;
;   It is recommended that for most "motion" commads, eg. quarter-circle-fwd,
;   you start off with a "release direction". This makes the command easier
;   to do.
;
; - time (optional)
;   Time allowed to do the command, given in game-ticks. The default
;   value for this is set in the [Defaults] section below. A typical
;   value is 15.
;
; - buffer.time (optional)
;   Time that the command will be buffered for. If the command is done
;   successfully, then it will be valid for this time. The simplest
;   case is to set this to 1. That means that the command is valid
;   only in the same tick it is performed. With a higher value, such
;   as 3 or 4, you can get a "looser" feel to the command. The result
;   is that combos can become easier to do because you can perform
;   the command early. Attacks just as you regain control (eg. from
;   getting up) also become easier to do. The side effect of this is
;   that the command is continuously asserted, so it will seem as if
;   you had performed the move rapidly in succession during the valid
;   time. To understand this, try setting buffer.time to 30 and hit
;   a fast attack, such as KFM's light punch.
;   The default value for this is set in the [Defaults] section below.
;   This parameter does not affect hold-only commands (eg. /F). It
;   will be assumed to be 1 for those commands.
;
; If you have two or more commands with the same name, all of them will
; work. You can use it to allow multiple motions for the same move.
;
; Some common commands examples are given below.
;
; [Command] ;Quarter circle forward + x
; name = "QCF_x"
; command = ~D, DF, F, x
;
; [Command] ;Half circle back + a
; name = "HCB_a"
; command = ~F, DF, D, DB, B, a
;
; [Command] ;Two quarter circles forward + y
; name = "2QCF_y"
; command = ~D, DF, F, D, DF, F, y
;
; [Command] ;Tap b rapidly
; name = "5b"
; command = b, b, b, b, b
; time = 30
;
; [Command] ;Charge back, then forward + z
; name = "charge_B_F_z"
; command = ~60$B, F, z
; time = 10
;
; [Command] ;Charge down, then up + c
; name = "charge_D_U_c"
; command = ~60$D, U, c
; time = 10


;-| Button Remapping |-----------------------------------------------------
; This section lets you remap the player's buttons (to easily change the
; button configuration). The format is:
;   old_button = new_button
; If new_button is left blank, the button cannot be pressed.
[Remap]
x = x
y = y
z = z
a = a
b = b
c = c
s = s

;-| Default Values |-------------------------------------------------------
[Defaults]
; Default value for the "time" parameter of a Command. Minimum 1.
command.time = 15

; Default value for the "buffer.time" parameter of a Command. Minimum 1,
; maximum 30.
command.buffer.time = 1


;-| Super Motions |--------------------------------------------------------
[Command]
name = "GDI"
command = ~F,DF,D,DB,B,y

[Command]
name = "GDI"
command = ~F,DF,D,DB,B,x

;-| Special Motions |------------------------------------------------------
[Command]
name = "EXS"
command = ~B,DB,D,DF,F,x+y

[Command]
name = "HS"
command = ~B,DB,D,DF,F,y

[Command]
name = "WS"
command = ~B,DB,D,DF,F,x

[Command]
name = "EXK"
command = ~D,U,x+y

[Command]
name = "HK"
command = ~D,U,y

[Command]
name = "WK"
command = ~D,U,x

[Command]
name = "Senpuzan"
command = x+y
time = 1

;-| Double Tap |-----------------------------------------------------------
[Command]
name = "FF"     ;Required (do not remove)
command = F, F
time = 10

[Command]
name = "BB"     ;Required (do not remove)
command = B, B
time = 10

;-| 2/3 Button Combination |-----------------------------------------------
[Command]
name = "recovery";Required (do not remove)
command = x+y
time = 1

;-| Dir + Button |---------------------------------------------------------
[Command]
name = "down_a"
command = /$D,a
time = 1

[Command]
name = "down_b"
command = /$D,b
time = 1

;-| Single Button |---------------------------------------------------------
[Command]
name = "a"
command = a
time = 1

[Command]
name = "b"
command = b
time = 1

[Command]
name = "WB"
command = D,DF,F,D,DF,F,x
time = 30

[Command]
name = "WB"
command = D,DF,F,D,DF,F,y
time = 30

[Command]
name = "c"
command = c
time = 1

[Command]
name = "x"
command = x
time = 1

[Command]
name = "y"
command = y
time = 1

[Command]
name = "z"
command = z
time = 1

[Command]
name = "start"
command = s
time = 1

;-| Hold Dir |--------------------------------------------------------------
[Command]
name = "holdfwd";Required (do not remove)
command = /$F
time = 1

[Command]
name = "holdback";Required (do not remove)
command = /$B
time = 1

[Command]
name = "holdup" ;Required (do not remove)
command = /$U
time = 1

[Command]
name = "holddown";Required (do not remove)
command = /$D
time = 1

;---------------------------------------------------------------------------
; 2. State entry
; --------------
; This is where you define what commands bring you to what states.
;
; Each state entry block looks like:
;   [State -1, Label]           ;Change Label to any name you want to use to
;                               ;identify the state with.
;   type = ChangeState          ;Don't change this
;   value = new_state_number
;   trigger1 = command = command_name
;   . . .  (any additional triggers)
;
; - new_state_number is the number of the state to change to
; - command_name is the name of the command (from the section above)
; - Useful triggers to know:
;   - statetype
;       S, C or A : current state-type of player (stand, crouch, air)
;   - ctrl
;       0 or 1 : 1 if player has control. Unless "interrupting" another
;                move, you'll want ctrl = 1
;   - stateno
;       number of state player is in - useful for "move interrupts"
;   - movecontact
;       0 or 1 : 1 if player's last attack touched the opponent
;                useful for "move interrupts"
;
; Note: The order of state entry is important.
;   State entry with a certain command must come before another state
;   entry with a command that is the subset of the first.
;   For example, command "fwd_a" must be listed before "a", and
;   "fwd_ab" should come before both of the others.
;
; For reference on triggers, see CNS documentation.
;
; Just for your information (skip if you're not interested):
; This part is an extension of the CNS. "State -1" is a special state
; that is executed once every game-tick, regardless of what other state
; you are in.


; Don't remove the following line. It's required by the CMD standard.
[Statedef -1]

;---------------------------------------------------------------------------
; Taikiri
[State -1, Taikiri]
type = ChangeState
value = 100
trigger1 = command = "FF"
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
; Hop Backwards
[State -1, Hop Backwards]
type = ChangeState
value = 105
trigger1 = command = "BB"
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
; WallJump
[State -1,WallJump]
type = changestate
triggerall = command = "holdfwd" && StateNo != 60 && PrevStateNo != 60 && ctrl
triggerall = anim = 42 || anim = 43
trigger1 = pos y < -40 && screenpos x < 35 && facing = 1 || pos y < -40 && screenpos x > 285 && facing = -1
value = 60
;---------------------------------------------------------------------------
; WallJump
[State -1,WallJump]
type = changestate
triggerall = command = "holdback" && StateNo != 60 && PrevStateNo != 60 && ctrl
triggerall = anim = 42 || anim = 43
trigger1 = pos y < -40 && screenpos x < 35 && facing = -1 || pos y < -40 && screenpos x > 285 && facing = 1
value = 60

;-------------------------------------------------------------------------------
; Weak Attack
[State -1, Weak Attack]
type = Changestate
value = 200
triggerall = command != "EXK"
triggerall = command != "WK"
triggerall = command != "WB"
triggerall = command != "GDI"
triggerall = command != "WS"
triggerall = command != "EXS"
triggerall = command != "Senpuzan"
triggerall = command = "x" && command != "holddown"
trigger1 = statetype = s
trigger1 = ctrl
trigger2 = stateno = 400 && movecontact

;-------------------------------------------------------------------------------
; Heavy Attack
[State -1, Heavy Attack]
type = Changestate
value = 206
triggerall = command != "EXK"
triggerall = command != "HK"
triggerall = command != "WB"
triggerall = command != "GDI"
triggerall = command != "HS"
triggerall = command != "EXS"
triggerall = command != "Senpuzan"
triggerall = command = "y" && command != "holddown"
trigger1 = statetype = s
trigger1 = ctrl
trigger2 = stateno = 204 && movecontact && p2life != 0
trigger3 = stateno = 202 && movecontact && p2life != 0

;-------------------------------------------------------------------------------
; C Weak Attack
[State -1, C Weak Attack]
type = Changestate
value = 400
triggerall = command = "x" && command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl

;-------------------------------------------------------------------------------
; C Heavy Attack
[State -1, C Heavy Attack]
type = Changestate
value = 402
triggerall = command = "y" && command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = stateno = 400 && movecontact

;-------------------------------------------------------------------------------
; A Weak Attack
[State -1, A Weak Attack]
type = Changestate
value = 600
triggerall = command = "x" && command != "holddown"
trigger1 = statetype = A
trigger1 = ctrl

;-------------------------------------------------------------------------------
; A Heavy Attack
[State -1, A Heavy Attack]
type = Changestate
value = 602
triggerall = command = "y" && command != "holddown"
trigger1 = statetype = A
trigger1 = ctrl

;-------------------------------------------------------------------------------
; Choyaku Surasshu
[State -1, Choyaku Surasshu]
type = Changestate
value = 604
triggerall = command = "holddown"
triggeraLL = statetype = A
triggerall = ctrl
trigger1 = command = "x" || command = "y"

;-------------------------------------------------------------------------------
; Grapple
[State -1, Grapple]
type = Changestate
value = 800
triggerall = command = "a" && command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl

;-------------------------------------------------------------------------------
; Fuu Tosu
[State -1, Fuu Tosu]
type = Changestate
value = 8331
triggerall = stateno != 605
triggerall = command = "a"
trigger1 = statetype = A
trigger1 = ctrl

;-------------------------------------------------------------------------------
; Fuu Tosu
[State -1, Fuu Tosu]
type = Changestate
value = 8332
triggerall = p2life != 0
triggerall = stateno = 605 && time > 1
trigger1 = command = "a"
trigger1 = statetype = A

;-------------------------------------------------------------------------------
; Senpuzan
[State -1, Senpuzan]
type = Changestate
value = 1000
triggerall = p2life != 0
triggerall = command != "EXS"
triggerall = command = "Senpuzan"
triggerall = life >= 70
trigger1 = statetype = S
trigger1 = ctrl

;-------------------------------------------------------------------------------
; W Koeikyaku
[State -1, W Koeikyaku]
type = Changestate
value = 1001
triggerall = p2life != 0
triggerall = command != "EXK"
triggerall = command = "WK"
trigger1 = statetype = S
trigger1 = ctrl || stateno = 40
trigger2 = stateno = 206 && movecontact
trigger3 = stateno = 400 && movecontact
trigger4 = stateno = 402 && movecontact

;-------------------------------------------------------------------------------
; H Koeikyaku
[State -1, H Koeikyaku]
type = Changestate
value = 10011
triggerall = p2life != 0
triggerall = command != "EXK"
triggerall = command = "HK"
trigger1 = statetype = S
trigger1 = ctrl || stateno = 40
trigger2 = stateno = 206 && movecontact
trigger3 = stateno = 400 && movecontact
trigger4 = stateno = 402 && movecontact

;-------------------------------------------------------------------------------
; EX Koeikyaku
[State -1, EX Koeikyaku]
type = Changestate
value = 10012
triggerall = p2life != 0
triggerall = power >= 500
triggerall = command = "EXK"
trigger1 = statetype = S
trigger1 = ctrl || stateno = 40
trigger2 = stateno = 206 && movecontact
trigger3 = stateno = 400 && movecontact
trigger4 = stateno = 402 && movecontact

;-------------------------------------------------------------------------------
; W Soukeiha
[State -1, W Soukeiha]
type = Changestate
value = 1002
triggerall = p2life != 0
triggerall = command != "EXS"
triggerall = command = "WS"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = stateno = 206 && movecontact
trigger3 = stateno = 100 && movecontact
trigger4 = stateno = 400 && movecontact

;-------------------------------------------------------------------------------
; H Soukeiha
[State -1, H Soukeiha]
type = Changestate
value = 10021
triggerall = p2life != 0
triggerall = command != "EXS"
triggerall = command = "HS"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = stateno = 206 && movecontact
trigger3 = stateno = 100 && movecontact
trigger4 = stateno = 400 && movecontact

;-------------------------------------------------------------------------------
; EX Soukeiha
[State -1, EX Soukeiha]
type = Changestate
value = 10022
triggerall = p2life != 0
triggerall = power >= 500
triggerall = command = "EXS"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = stateno = 206 && movecontact
trigger3 = stateno = 100 && movecontact
trigger4 = stateno = 400 && movecontact

;-------------------------------------------------------------------------------
; Royal Demon Impaler
[State -1, Royal Demon Impaler]
type = Changestate
value = 3020
triggerall = p2life != 0
triggerall = power >= 1000
triggerall = command = "GDI"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = stateno = 206 && movecontact
trigger3 = stateno = 100 && movecontact
trigger4 = stateno = 400 && movecontact

;-------------------------------------------------------------------------------
; Wild Barrage
[State -1, Wild Barrage]
type = Changestate
value = 4000
triggerall = p2life != 0
triggerall = power >= 2000
triggerall = command = "WB"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = stateno = 206 && movecontact
trigger3 = stateno = 400 && movecontact
